﻿using System;
using System.Runtime.InteropServices;
using System.Text;
using Interop.Plantronics;

namespace Plantronics_Mobile_Caller_ID_Sample
{
    internal class Program
    {
        static ICOMATDCommand _atdCommand;
        static ICOMMobilePresenceEvents_Event _mobileEvents;

        private static COMDevice _device;

        static void Main()
        {
            //Get a valid _device
            COMSessionManager mgr = new COMSessionManager();
            COMSession sess;
            mgr.Register("My Session", out sess);
            _device = sess.GetActiveDevice();

            //Cast HostCommand and init _atdCommand and _mobileEvents
            _atdCommand = _device.HostCommand as ICOMATDCommand;
            _mobileEvents = _device as ICOMMobilePresenceEvents_Event;

            Menu();
            int choice = 0;
            while (choice != 5)
            {
                choice = Convert.ToInt32(Console.ReadLine());

                switch (choice)
                {
                    case 1:
                        if (_mobileEvents != null)
                        {
                            _mobileEvents.onPresenceChanged += mobileEvents_PresenceChanged;
                            Console.WriteLine("Registered.");
                        }
                        break;
                    case 2:
                        if (_mobileEvents != null)
                        {
                            _mobileEvents.onPresenceChanged -= mobileEvents_PresenceChanged;
                            Console.WriteLine("Unregistered.");
                        }
                        break;
                    case 3:
                        MakeMobileCall();
                        break;
                    case 4:
                        MobileRedial();
                        break;
                    default:
                        Console.WriteLine("Please enter a value between 1 and 5. \r\n");
                        Menu();
                        break;
                }
            }
        }

        private static void Menu()
        {
            Console.WriteLine("Plantronics Mobile Caller ID Sample\r\n" +
                              "\r\n" +
                              "1. Register Mobile Presence Events. \r\n" +
                              "2. Unregister Mobile Presence Events. \r\n" +
                              "3. Make a call using the mobile phone. \r\n" +
                              "4. Redial using Caller Id. \r\n" +
                              "5. Exit application.");
        }

        private static void mobileEvents_PresenceChanged(COMMobilePresenceEventArgs args)
        {
            StringBuilder strB = new StringBuilder();
            strB.Append("Mobile Presence: ");
            if (args.MobileCallState == DeviceMobileCallState.MobileCallState_CallerID)
                strB.Append(String.Format("{0} = {1}", args.MobileCallState, args.CallerId));
            else
                strB.Append(String.Format("{0}", args.MobileCallState));
            strB.Append(String.Format(" ( {0} )", DateTime.Now.TimeOfDay));
            strB.AppendLine();

            Console.WriteLine(strB.ToString());
        }
        
        private static void MakeMobileCall()
        {
            try
            {
                Console.WriteLine("Please enter a phone number: ");
                string number = Console.ReadLine();
                if (_atdCommand != null)
                {
                    Console.WriteLine("Calling " + number);
                    _atdCommand.MakeMobileCall(number);
                }
            }
            catch (COMException e)
            {
                Console.WriteLine(e.ToString());
            }
        }

        private static void MobileRedial()
        {
            try
            {
                if (_atdCommand != null)
                {
                    if (_atdCommand.CallerId != String.Empty)
                    {
                        Console.WriteLine("Redialing " + _atdCommand.CallerId);
                        _atdCommand.MakeMobileCall(_atdCommand.CallerId);
                    }
                }
            }
            catch (COMException e)
            {
                Console.WriteLine(e.ToString());
            }
        }
    }
}
